@@ -2,17 +2,21 @@
 from plone.stringinterp.adapters import BaseSubstitution
 from Products.CMFCore.interfaces import IContentish
 from zope.component import adapter
-from plone.stringinterp import _ as stringinterp_mf
 from redturtle.volto import _
 
+try:
+    from plone.stringinterp import _ as stringinterp_mf
+except ImportError:
+    # plone 6
+    from plone.base import PloneMessageFactory as stringinterp_mf
+
 
 @adapter(IContentish)
 class VoltoUrlSubstitution(BaseSubstitution):
-
-    category = stringinterp_mf(u"All Content")
+    category = stringinterp_mf("All Content")
     description = _(
         "stringinterp_volto_url",
-        default=u'Volto URL: Content url without "/api".',
+        default='Volto URL: Content url without "/api".',
     )
 
     def safe_call(self):
@@ -26,11 +30,10 @@ class VoltoUrlSubstitution(BaseSubstitution):
 
 @adapter(IContentish)
 class VoltoParentUrlSubstitution(BaseSubstitution):
-
-    category = stringinterp_mf(u"All Content")
+    category = stringinterp_mf("All Content")
     description = _(
         "stringinterp_volto_parent_url",
-        default=u'Volto Parent URL: Content url without "/api".',
+        default='Volto Parent URL: Content url without "/api".',
     )
 
     def safe_call(self):
